
.. _sardana-devel-macro-parameter-examples:

=========================
Macro parameter examples
=========================

This chapter consists of a series of examples demonstrating how to declare
macros which receive parameter(s).


.. literalinclude:: ../../../../src/sardana/macroserver/macros/examples/parameters.py
   :language: python
   :linenos:
